@@ -16,19 +16,20 @@
 #    under the License.
 
 import fixtures
-from keystoneclient import fixture as keystone_client_fixture
+import mock
 from requests_mock.contrib import fixture as requests_mock_fixture
 
 from cinderclient import client
 from cinderclient import exceptions
 from cinderclient import shell
-from cinderclient.tests.unit.fixture_data import base as fixture_base
+from cinderclient.v1 import shell as shell_v1
+
 from cinderclient.tests.unit.fixture_data import keystone_client
 from cinderclient.tests.unit import utils
 from cinderclient.tests.unit.v1 import fakes
-from cinderclient.v1 import shell as shell_v1
 
 
+@mock.patch.object(client, 'Client', fakes.FakeClient)
 class ShellTest(utils.TestCase):
 
     FAKE_ENV = {
@@ -50,36 +51,13 @@ class ShellTest(utils.TestCase):
         self.shell = shell.OpenStackCinderShell()
 
         # HACK(bcwaldon): replace this when we start using stubs
-        self.old_get_client_class = client.get_client_class
-        client.get_client_class = lambda *_: fakes.FakeClient
+        self.old_client_class = client.Client
+        client.Client = fakes.FakeClient
 
         self.requests = self.useFixture(requests_mock_fixture.Fixture())
         self.requests.register_uri(
             'GET', keystone_client.BASE_URL,
-            text=keystone_client.keystone_request_callback
-        )
-        token = keystone_client_fixture.V2Token()
-        s = token.add_service('volume', 'cinder')
-        s.add_endpoint(public='http://127.0.0.1:8776')
-
-        self.requests.post(keystone_client.BASE_URL + 'v2.0/tokens',
-                           json=token)
-        self.requests.get(
-            'http://127.0.0.1:8776',
-            json=fixture_base.generate_version_output()
-        )
-
-    def tearDown(self):
-        # For some method like test_image_meta_bad_action we are
-        # testing a SystemExit to be thrown and object self.shell has
-        # no time to get instantatiated which is OK in this case, so
-        # we make sure the method is there before launching it.
-        if hasattr(self.shell, 'cs'):
-            self.shell.cs.clear_callstack()
-
-        # HACK(bcwaldon): replace this when we start using stubs
-        client.get_client_class = self.old_get_client_class
-        super(ShellTest, self).tearDown()
+            text=keystone_client.keystone_request_callback)
 
     def run_command(self, cmd):
         self.shell.main(cmd.split())
@@ -118,7 +96,7 @@ class ShellTest(utils.TestCase):
                 'id': 1234, 'display_name': 'sample-volume',
                 'os-vol-tenant-attr:tenant_id': 'fake_tenant'})
         shell_v1._translate_volume_keys([v])
-        self.assertEqual(v.tenant_id, 'fake_tenant')
+        self.assertEqual('fake_tenant', v.tenant_id)
 
     def test_list(self):
         self.run_command('list')
