@@ -145,6 +145,7 @@ class FakeHTTPClient(fake_v2.FakeHTTPClient):
                 'state': 'up',
                 'updated_at': datetime(2012, 10, 29, 13, 42, 2),
                 'cluster': 'cluster1',
+                'backend_state': 'up',
             },
             {
                 'id': 2,
@@ -155,6 +156,7 @@ class FakeHTTPClient(fake_v2.FakeHTTPClient):
                 'state': 'down',
                 'updated_at': datetime(2012, 9, 18, 8, 3, 38),
                 'cluster': 'cluster1',
+                'backend_state': 'down',
             },
             {
                 'id': 3,
@@ -174,6 +176,11 @@ class FakeHTTPClient(fake_v2.FakeHTTPClient):
         if not self.api_version.matches('3.7'):
             for svc in services:
                 del svc['cluster']
+
+        if not self.api_version.matches('3.49'):
+            for svc in services:
+                if svc['binary'] == 'cinder-volume':
+                    del svc['backend_state']
         return (200, {}, {'services': services})
 
     #
@@ -606,6 +613,17 @@ class FakeHTTPClient(fake_v2.FakeHTTPClient):
                                             }
                          }
 
+    def post_workers_cleanup(self, **kw):
+        response = {
+            'cleaning': [{'id': '1', 'cluster_name': 'cluster1',
+                          'host': 'host1', 'binary': 'binary'},
+                         {'id': '3', 'cluster_name': 'cluster1',
+                          'host': 'host3', 'binary': 'binary'}],
+            'unavailable': [{'id': '2', 'cluster_name': 'cluster2',
+                             'host': 'host2', 'binary': 'binary'}],
+        }
+        return 200, {}, response
+
     #
     # resource filters
     #
