@@ -693,6 +693,11 @@ class ShellTest(utils.TestCase):
                          'manageable-list fakehost --detailed False')
         self.assert_called('GET', '/manageable_volumes?host=fakehost')
 
+    def test_volume_manageable_list_cluster(self):
+        self.run_command('--os-volume-api-version 3.17 '
+                         'manageable-list --cluster dest')
+        self.assert_called('GET', '/manageable_volumes/detail?cluster=dest')
+
     def test_snapshot_manageable_list(self):
         self.run_command('--os-volume-api-version 3.8 '
                          'snapshot-manageable-list fakehost')
@@ -708,6 +713,36 @@ class ShellTest(utils.TestCase):
                          'snapshot-manageable-list fakehost --detailed False')
         self.assert_called('GET', '/manageable_snapshots?host=fakehost')
 
+    def test_snapshot_manageable_list_cluster(self):
+        self.run_command('--os-volume-api-version 3.17 '
+                         'snapshot-manageable-list --cluster dest')
+        self.assert_called('GET', '/manageable_snapshots/detail?cluster=dest')
+
+    @ddt.data('', 'snapshot-')
+    def test_manageable_list_cluster_before_3_17(self, prefix):
+        self.assertRaises(exceptions.UnsupportedAttribute,
+                          self.run_command,
+                          '--os-volume-api-version 3.16 '
+                         '%smanageable-list --cluster dest' % prefix)
+
+    @mock.patch('cinderclient.shell.CinderClientArgumentParser.error')
+    @ddt.data('', 'snapshot-')
+    def test_manageable_list_mutual_exclusion(self, prefix, error_mock):
+        error_mock.side_effect = SystemExit
+        self.assertRaises(SystemExit,
+                          self.run_command,
+                          '--os-volume-api-version 3.17 '
+                         '%smanageable-list fakehost --cluster dest' % prefix)
+
+    @mock.patch('cinderclient.shell.CinderClientArgumentParser.error')
+    @ddt.data('', 'snapshot-')
+    def test_manageable_list_missing_required(self, prefix, error_mock):
+        error_mock.side_effect = SystemExit
+        self.assertRaises(SystemExit,
+                          self.run_command,
+                          '--os-volume-api-version 3.17 '
+                         '%smanageable-list' % prefix)
+
     def test_list_messages(self):
         self.run_command('--os-volume-api-version 3.3 message-list')
         self.assert_called('GET', '/messages')
@@ -1194,7 +1229,7 @@ class ShellTest(utils.TestCase):
                                'metadata': {'k1': 'v1', 'k2': 'v2'},
                                'bootable': bootable}}
         if cluster:
-            expected['cluster'] = cluster
+            expected['volume']['cluster'] = cluster
         self.assert_called_anytime('POST', '/os-volume-manage', body=expected)
 
     def test_volume_manage_before_3_16(self):
@@ -1206,3 +1241,23 @@ class ShellTest(utils.TestCase):
                           '--name foo --description bar --bootable '
                           '--volume-type baz --availability-zone az '
                           '--metadata k1=v1 k2=v2')
+
+    def test_worker_cleanup_before_3_24(self):
+        self.assertRaises(SystemExit,
+                          self.run_command,
+                          'work-cleanup fakehost')
+
+    def test_worker_cleanup(self):
+        self.run_command('--os-volume-api-version 3.24 '
+                         'work-cleanup --cluster clustername --host hostname '
+                         '--binary binaryname --is-up false --disabled true '
+                         '--resource-id uuid --resource-type Volume')
+        expected = {'cluster_name': 'clustername',
+                    'host': 'hostname',
+                    'binary': 'binaryname',
+                    'is_up': 'false',
+                    'disabled': 'true',
+                    'resource_id': 'uuid',
+                    'resource_type': 'Volume'}
+
+        self.assert_called('POST', '/workers/cleanup', body=expected)
