@@ -17,19 +17,16 @@
 Volume snapshot interface (1.1 extension).
 """
 
-try:
-    from urllib import urlencode
-except ImportError:
-    from urllib.parse import urlencode
-
 from cinderclient import base
-import six
+from cinderclient import utils
 
 
 class Snapshot(base.Resource):
     """
     A Snapshot is a point-in-time snapshot of an openstack volume.
     """
+    NAME_ATTR = "display_name"
+
     def __repr__(self):
         return "<Snapshot: %s>" % self.id
 
@@ -54,7 +51,7 @@ class Snapshot(base.Resource):
         return self._info.get('os-extended-snapshot-attributes:project_id')
 
     def reset_state(self, state):
-        """Update the snapshot with the privided state."""
+        """Update the snapshot with the provided state."""
         self.manager.reset_state(self, state)
 
     def set_metadata(self, metadata):
@@ -110,23 +107,7 @@ class SnapshotManager(base.ManagerWithFind):
 
         :rtype: list of :class:`Snapshot`
         """
-
-        if search_opts is None:
-            search_opts = {}
-
-        qparams = {}
-
-        for opt, val in six.iteritems(search_opts):
-            if val:
-                qparams[opt] = val
-
-        # Transform the dict to a sequence of two-element tuples in fixed
-        # order, then the encoded string will be consistent in Python 2&3.
-        if qparams:
-            new_qparams = sorted(qparams.items(), key=lambda x: x[0])
-            query_string = "?%s" % urlencode(new_qparams)
-        else:
-            query_string = ""
+        query_string = utils.build_query_param(search_opts, True)
 
         detail = ""
         if detailed:
